==> kexi-3.0.1.tar.xz: kexi-3.0.1/src/plugins/forms/widgets/mapbrowser/MapBrowserFactory.h <==
/*
    <one line to give the library's name and an idea of what it does.>
    Copyright (C) 2011  Radosław Wicik <radoslaw@wicik.pl>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef MAPBROWSERFACTORY_H
#define MAPBROWSERFACTORY_H

#include "kexidbfactorybase.h"

//! Factory providing map browser widget
class MapBrowserFactory: public KexiDBFactoryBase
{
  Q_OBJECT
public:
    MapBrowserFactory(QObject* parent, const QVariantList &args);
    virtual ~MapBrowserFactory();
    virtual QWidget* createWidget(const QByteArray &classname, QWidget *parent, const char *name,
                                  KFormDesigner::Container *container,
                                  CreateWidgetOptions options = DefaultOptions);
    virtual bool createMenuActions(const QByteArray &classname, QWidget *w,
                                   QMenu *menu, KFormDesigner::Container *container);
    virtual bool startInlineEditing(InlineEditorCreationArguments& args);
    virtual bool previewWidget(const QByteArray &classname, QWidget *widget,
                               KFormDesigner::Container *container);

    virtual void setPropertyOptions(KPropertySet& set, const KFormDesigner::WidgetInfo& info, QWidget* w);
};

#endif // MAPBROWSERFACTORY_H

==> kexi_3.2.0.orig.tar.xz: kexi-3.2.0/src/plugins/forms/widgets/mapbrowser/MapBrowserFactory.h <==
/*
    <one line to give the library's name and an idea of what it does.>
    Copyright (C) 2011  Radosław Wicik <radoslaw@wicik.pl>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef MAPBROWSERFACTORY_H
#define MAPBROWSERFACTORY_H

#include "kexidbfactorybase.h"

//! Factory providing map browser widget
class MapBrowserFactory: public KexiDBFactoryBase
{
  Q_OBJECT
public:
    MapBrowserFactory(QObject* parent, const QVariantList &args);
    virtual ~MapBrowserFactory();
    QWidget *createWidget(const QByteArray &classname, QWidget *parent, const char *name,
                          KFormDesigner::Container *container,
                          CreateWidgetOptions options = DefaultOptions) override Q_REQUIRED_RESULT;
    virtual bool createMenuActions(const QByteArray &classname, QWidget *w,
                                   QMenu *menu, KFormDesigner::Container *container);
    virtual bool startInlineEditing(InlineEditorCreationArguments& args);
    virtual bool previewWidget(const QByteArray &classname, QWidget *widget,
                               KFormDesigner::Container *container);

    virtual void setPropertyOptions(KPropertySet& set, const KFormDesigner::WidgetInfo& info, QWidget* w);
};

#endif // MAPBROWSERFACTORY_H
